const { get } = require('lodash')
const { init: initAxios } = require('@kryonsystems/kryon-axios')
const logger = require('@kryonsystems/kryon-logger').getAppLogger()

const init = async ({ serviceConfig }) => {
	const caBundleName = get(serviceConfig, 'webhook.certificateFileName', '')

	const { axiosInstance } = await initAxios({ caBundleName })

	const handleMessage = makeHandleMessage({ axiosInstance })

	return {
		handleMessage
	}
}

const makeHandleMessage = ({ axiosInstance }) => async ({ message }) => {
	const doc = get(message, 'doc')
	const body = get(doc, 'body')
	const tenantId = get(doc, 'tenantId')
	const url = get(doc, 'url')

	try {
		logger.info(`Sending notification to ${url}, tenantId: ${tenantId}`)

		await axiosInstance.post(url, body)
	} catch (err) {
		logger.error({ err }, `Failed to send webhook notification. tenantId: ${tenantId}, url: ${url}`)

		throw err
	}

	return {
		success: true
	}
}

Object.assign(module.exports, {
	init
})
